===============================
composeinfo -- Compose metadata
===============================

.. automodule:: productmd.composeinfo


Constants
=========

.. _COMPOSE_TYPES:
.. autodata:: productmd.composeinfo.COMPOSE_TYPES

.. _LABEL_NAMES:
.. autodata:: productmd.composeinfo.LABEL_NAMES

.. _VARIANT_TYPES:
.. autodata:: productmd.composeinfo.VARIANT_TYPES


Classes
=======

.. autoclass:: productmd.composeinfo.ComposeInfo
    :members:
    :inherited-members:


.. autoclass:: productmd.composeinfo.Compose
    :members:


.. autoclass:: productmd.composeinfo.Release
    :members:


.. autoclass:: productmd.composeinfo.BaseProduct
    :members:


.. autoclass:: productmd.composeinfo.Variants
    :members:


.. autoclass:: productmd.composeinfo.Variant
    :members:


.. autoclass:: productmd.composeinfo.VariantPaths
    :members:


Private Classes
===============

.. autoclass:: productmd.composeinfo.VariantBase
    :members:
    :special-members:
